==> shadowshell-0.0.35-py3-none-any.whl: shadowshell/bootstrap.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import os
# import requests
from datetime import datetime
from shadowshell.logger_factory import LoggerFactory
import time

logger = LoggerFactory().get_logger()

"""
ShadowShell

@author: shadowshell
"""
class ShadowShell:

    def __init__(self):
        self.logger = LoggerFactory().get_logger()
        pass

    def hello(self):
        print("Hi, i am shadow shell." )
        current_time = datetime.now()
        formatted_current_time = current_time.strftime("%Y-%m-%d %H:%M:%S")
        print("Now is " + formatted_current_time)

    def test(self, func, **args):
        try:
            self.logger.debug('-->> Ready')
            func(**args)            
            self. logger.debug('-->> Do something')
        except Exception as e:
            self.logger.error(e)
        except:
            self.logger.error(sys.exc_info()[0])
        finally:
            self.logger.debug('-->> Done')
        return
    
    # def request(self):
    #     print(requests.get("https://wwww.baidu.com"))

from shadowshell.logger_factory import LoggerFactory
import sys

class TestTemplate:

    def __init__(self):
        self.logger = LoggerFactory().get_logger()
        return

    def test(self):

        try:
            self.logger.debug('-->> Ready')
            
            self.test0()

            self.logger.debug('-->> Do something')

        except Exception as e:
            self.logger.error(e)
        except:
            self.logger.error(sys.exc_info()[0])
        finally:
            self.logger.debug('-->> Done')
            return

    def test0(self):
        self.logger.debug('Nothing')
        return

def performance_monitor(class_name=None):
    def decorator(func):
        def wrapper(*args, **kwargs):
            start = time.perf_counter()
            try:
                result = func(*args, **kwargs)
            finally:
                elapsed = time.perf_counter() - start
                if (class_name is not None):
                    logger.info(f"[PERFORMANCE_MONITOR][{class_name}][{func.__name__}] has ran, time elapsed:{elapsed:.6f}s.")
                else:
                    logger.info(f"[PERFORMANCE_MONITOR][{func.__name__}] has ran, time elapsed:{elapsed:.6f}s.")
                return result
        return wrapper
    return decorator

def function_monitor(class_name=None):
    def decorator(func):
        def wrapper(*args, **kwargs):
            start = time.perf_counter()
            try:
                result = func(*args, **kwargs)    
            except Exception as e:
                logger.error(e)
            except:
                logger.error(sys.exc_info()[0])
            finally:
                elapsed = time.perf_counter() - start
                if (class_name is not None):
                    logger.info(f"[FUNCTION_MONITOR][{class_name}][{func.__name__}] has ran, time elapsed:{elapsed:.6f}s.")            
                else:
                    logger.info(f"[FUNCTION_MONITOR][{func.__name__}] has ran, time elapsed:{elapsed:.6f}s.")
                return result
        return wrapper
    return decorator

def testserver():
    os.system("ping shadowshell.xyz")
    
def cnnserver():
    os.system("ssh admin@shadowshell.xyz")

def hello(**args):
    logger.info(f"Hello {args}")

def shadowshell(**args):
    logger.info(f"shadow shell : {args}")

def invoke_with_tmpl(func, **args):
    try:
        logger.debug('-->> Ready')

        func(**args)
        
        logger.debug('-->> Do something')
    except Exception as e:
        logger.error(e)
    except:
        logger.error(sys.exc_info()[0])
    finally:
        logger.debug('-->> Done')
    return

if __name__ == "__main__":
    #ShadowShell().test()
    invoke_with_tmpl(shadowshell)
    invoke_with_tmpl(shadowshell, a='1')
    invoke_with_tmpl(shadowshell, a='1', b='2')
    invoke_with_tmpl(hello, a='shell', b='shadow')

==> shadowshell-0.0.37-py3-none-any.whl: shadowshell/bootstrap.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import os
# import requests
from datetime import datetime
from shadowshell.logger_factory import LoggerFactory
import time

logger = LoggerFactory().get_logger()

"""
ShadowShell

@author: shadowshell
"""
class ShadowShell:

    def __init__(self):
        self.logger = LoggerFactory().get_logger()
        pass

    def hello(self):
        print("Hi, i am shadow shell." )
        current_time = datetime.now()
        formatted_current_time = current_time.strftime("%Y-%m-%d %H:%M:%S")
        print("Now is " + formatted_current_time)

    def test(self, func, **args):
        try:
            self.logger.debug('-->> Ready')
            func(**args)            
            self. logger.debug('-->> Do something')
        except Exception as e:
            self.logger.error(e)
        except:
            self.logger.error(sys.exc_info()[0])
        finally:
            self.logger.debug('-->> Done')
        return
    
    # def request(self):
    #     print(requests.get("https://wwww.baidu.com"))

from shadowshell.logger_factory import LoggerFactory
import sys

class TestTemplate:

    def __init__(self):
        self.logger = LoggerFactory().get_logger()
        return

    def test(self):

        try:
            self.logger.debug('-->> Ready')
            
            self.test0()

            self.logger.debug('-->> Do something')

        except Exception as e:
            self.logger.error(e)
        except:
            self.logger.error(sys.exc_info()[0])
        finally:
            self.logger.debug('-->> Done')
            return

    def test0(self):
        self.logger.debug('Nothing')
        return

def performance_monitor(class_name=None):
    def decorator(func):
        def wrapper(*args, **kwargs):
            start = time.perf_counter()
            result = None
            try:
                result = func(*args, **kwargs)
            finally:
                elapsed = time.perf_counter() - start
                if (class_name is not None):
                    logger.info(f"[PERFORMANCE_MONITOR][{class_name}.{func.__name__}] has ran, time elapsed:{elapsed:.6f}s.")
                else:
                    logger.info(f"[PERFORMANCE_MONITOR][{func.__name__}] has ran, time elapsed:{elapsed:.6f}s.")
                return result
        return wrapper
    return decorator

def function_monitor(class_name=None):
    def decorator(func):
        def wrapper(*args, **kwargs):
            start = time.perf_counter()
            result = None
            try:
                result = func(*args, **kwargs)    
            except Exception as e:
                logger.error(e)
            except:
                logger.error(sys.exc_info()[0])
            finally:
                elapsed = time.perf_counter() - start
                if (class_name is not None):
                    logger.info(f"[FUNCTION_MONITOR][{class_name}.{func.__name__}] has ran, time elapsed:{elapsed:.6f}s.")            
                else:
                    logger.info(f"[FUNCTION_MONITOR][{func.__name__}] has ran, time elapsed:{elapsed:.6f}s.")
                return result
        return wrapper
    return decorator

def testserver():
    os.system("ping shadowshell.xyz")
    
def cnnserver():
    os.system("ssh admin@shadowshell.xyz")

def hello(**args):
    logger.info(f"Hello {args}")

def shadowshell(**args):
    logger.info(f"shadow shell : {args}")

def invoke_with_tmpl(func, **args):
    try:
        logger.debug('-->> Ready')

        func(**args)
        
        logger.debug('-->> Do something')
    except Exception as e:
        logger.error(e)
    except:
        logger.error(sys.exc_info()[0])
    finally:
        logger.debug('-->> Done')
    return

if __name__ == "__main__":
    #ShadowShell().test()
    invoke_with_tmpl(shadowshell)
    invoke_with_tmpl(shadowshell, a='1')
    invoke_with_tmpl(shadowshell, a='1', b='2')
    invoke_with_tmpl(hello, a='shell', b='shadow')
